@@ -48,6 +48,7 @@ static struct option long_options[] =
 	{"fast", no_argument, 0, 0},
 	{"SAMinput", no_argument, 0, 0},
 	{"reportPairedMultiBest",  no_argument, 0, 0},
+	{"BCLinput", no_argument, 0, 0},
 	{"sv", no_argument, 0, 0},
 	{"longDel", no_argument, 0, 0},
 	{"exonAnnotationScreenOut", required_argument, 0, 0},
@@ -495,6 +496,10 @@ int parse_opts_aligner(int argc , char ** argv, global_context_t * global_contex
 				{
 					global_context->config.memory_use_multiplex = atof(optarg);
 				}
+				else if(strcmp("BCLinput", long_options[option_index].name)==0) 
+				{
+					global_context->config.is_BCL_input=1;
+				}
 				else if(strcmp("rg-id", long_options[option_index].name)==0) 
 				{
 					strcpy(global_context->config.read_group_id, optarg);
