@@ -96,9 +96,9 @@ typedef struct{
 #define GRA_DEBUG_ASSEMBLING 4
 
 typedef struct {
-	char input_file_name [300];
-	char input_file_name2 [300];
-	char output_file_name [300];
+	char input_file_name [MAX_FILE_NAME_LENGTH];
+	char input_file_name2 [MAX_FILE_NAME_LENGTH];
+	char output_file_name [MAX_FILE_NAME_LENGTH];
 	int is_BAM_input;
 	int total_threads;
 	int shortest_read_allowed;
@@ -134,7 +134,7 @@ typedef struct {
 	lnhash_t assembling_index;
 
 	// ====== Global System ======
-	char tmp_file_prefix[300];
+	char tmp_file_prefix[MAX_FILE_NAME_LENGTH];
 	unsigned int random_seeds[8];
 	pid_t system_pid;
 
@@ -365,7 +365,7 @@ int calc_2r_overlapping(GRA_global_context_t * global_context, char * r1, char *
 int GRA_trim_reads(GRA_global_context_t * global_context)
 {
 	int line_buff_len = MAX_READ_LENGTH * 2 + MAX_READ_NAME_LEN + MAX_CHROMOSOME_NAME_LEN * 3 + 500; 
-	char tmp_fname[300],
+	char tmp_fname[MAX_FILE_NAME_LENGTH],
 		* read1_tmp = malloc(line_buff_len),
 		* line_buff = malloc(line_buff_len),
 		* in_sequence = malloc(MAX_READ_LENGTH),
@@ -707,7 +707,7 @@ int GRA_build_read_index(GRA_global_context_t* global_context)
 
 	lnhash_create(&global_context -> assembling_index, 666661);
 
-	char tmp_fname[300],
+	char tmp_fname[MAX_FILE_NAME_LENGTH],
 		* in_sequence_1 = malloc(MAX_READ_LENGTH),
 		* in_quality_string_1 = malloc(MAX_READ_LENGTH),
 		* in_sequence_2 = malloc(MAX_READ_LENGTH),
@@ -808,7 +808,7 @@ int GRA_mark_read_extension(GRA_global_context_t* global_context)
 	unsigned long long report_step = max(1, global_context -> all_fragments/20);
 	FILE  * fp_fraglist;
 	GRA_frag_properties_t * frag_prop;
-	char tmp_fname[300],
+	char tmp_fname[MAX_FILE_NAME_LENGTH],
 		* in_sequence_1 = malloc(MAX_READ_LENGTH),
 		* in_quality_string_1 = malloc(MAX_READ_LENGTH),
 		* in_sequence_2 = malloc(MAX_READ_LENGTH),
@@ -1474,7 +1474,7 @@ int GRA_reassemble_reads_LR(GRA_global_context_t* global_context, int to_right)
 
 			if(global_context -> debug_flags & GRA_DEBUG_ASSEMBLING)
 			{
-				char spaces[300];
+				char spaces[MAX_FILE_NAME_LENGTH];
 				SUBREADprintf(" === %s {%d} V=%d, MM=%d === NEXT_REV=%d \n", to_right?">>>":"<<<", is_current_read2_extension?2:1, current_read_votes, mm, next_reversed_map);
 
 				for(xk1=0;xk1< current_map_pos; xk1++)
@@ -1671,7 +1671,7 @@ void GRA_destroy_context(GRA_global_context_t* global_context)
 
 int GRA_memory_map(GRA_global_context_t* global_context)
 {
-	char tmp_fname[300];
+	char tmp_fname[MAX_FILE_NAME_LENGTH];
 
 	sprintf(tmp_fname, "%s.fragproperties", global_context -> tmp_file_prefix);
 
@@ -1756,7 +1756,7 @@ int main(int argc, char ** argv)
 		return -1;
 	}
 
-	char * tmptmp = malloc(320);
+	char * tmptmp = malloc(MAX_FILE_NAME_LENGTH);
 	while ((c = getopt_long (argc, argv, "2:t:Q:V:L:i:I:o:bHCR6", GRA_long_options, &option_index)) != -1)
 		switch(c)
 		{
