@@ -50,7 +50,7 @@ $SH_CMD data/compare.sh data/test-minimum.sam data/test-minimum.ora data/test-mi
 
 # by default it is in SAM.
 $SH_CMD data/compare.sh data/test-minimum.sam data/test-minimum.ora data/test-minimum.GTF "-p " "SAM format input"
-$SH_CMD data/compare.sh data/test-minimum.bam data/test-minimum.ora data/test-minimum.GTF "-p -b " "BAM format input" 
+$SH_CMD data/compare.sh data/test-minimum.bam data/test-minimum.ora data/test-minimum.GTF "-p " "BAM format input" 
 
 # by default it is non-strand specific.
 $SH_CMD data/compare.sh data/test-minimum.sam data/test-minimum.ora data/test-minimum.GTF "-p -s 0 " "unstranded read summarization"
